@@ -49,7 +49,7 @@ class Mouse(Backend):
 
 		[TOC]
 
-		## Things to know
+		## Things to know
 
 		### Creating a Mouse
 
@@ -60,7 +60,7 @@ class Mouse(Backend):
 		~~~
 
 		Optionally, you can pass [Response keywords](#response-keywords) to
-		`Keyboard()` to set the default behavior:
+		`Mouse()` to set the default behavior:
 
 		~~~ .python
 		my_mouse = Mouse(timeout=2000)
@@ -98,37 +98,37 @@ class Mouse(Backend):
 		- `timeout` specifies a timeout value in milliseconds, or is set to
 		  `None` to disable the timeout.
 		- `buttonlist` specifies a list of buttons that are accepted, or is set
-		  to `None` accept all keys.
+		  to `None` accept all buttons.
 		- `visible` indicates whether the mouse cursor becomes visible when a
 		  click is collected (`True` or `False`). To immediately change cursor
-		  visibility, use [mouse.show_cursor].
+		  visibility, use `Mouse.show_cursor()`.
 
 		~~~ .python
 		# Get a left or right button press with a timeout of 3000 ms
 		my_mouse = Mouse()
-		button, time = my_mouse.get_key(buttonlist=[1,3], timeout=3000)
+		button, time = my_mouse.get_click(buttonlist=[1,3], timeout=3000)
 		~~~
 
 		Response keywords only affect the current operation (except when passed
-		to [mouse.\_\_init\_\_][__init__]). To change the behavior for all
+		to `Mouse()` when creating the object). To change the behavior for all
 		subsequent operations, set the response properties directly:
 
 		~~~ .python
-		# Get two key left or right presses with a 5000 ms timeout
+		# Get two left or right presses with a 5000 ms timeout
 		my_mouse = Mouse()
-		my_mouse.keylist = [1,3]
+		my_mouse.buttonlist = [1,3]
 		my_mouse.timeout = 5000
-		button1, time1 = my_mouse.get_button()
-		button2, time2 = my_mouse.get_button()
+		button1, time1 = my_mouse.get_click()
+		button2, time2 = my_mouse.get_click()
 		~~~
 
-		Or pass the response keywords to [mouse.\_\_init\_\_][__init__]:
+		Or pass the response keywords to `Mouse()` when creating the object:
 
 		~~~ .python
-		# Get two key left or right presses with a 5000 ms timeout
-		my_mouse = Mouse(keylist=[1,3], timeout=5000)
-		button1, time1 = my_mouse.get_button()
-		button2, time2 = my_mouse.get_button()
+		# Get two left or right presses with a 5000 ms timeout
+		my_mouse = Mouse(buttonlist=[1,3], timeout=5000)
+		button1, time1 = my_mouse.get_click()
+		button2, time2 = my_mouse.get_click()
 		~~~
 	"""
 
@@ -149,8 +149,8 @@ class Mouse(Backend):
 
 		keyword-dict:
 			resp_args:
-				Optional [response keywords] that will be used as the default
-				for this `Mouse` object.
+				Optional [response keywords](#response-keywords) that will be
+				used as the default for this `Mouse` object.
 
 		example: |
 			my_mouse = Mouse(buttonlist=[1, 2], timeout=2000)
@@ -167,7 +167,7 @@ class Mouse(Backend):
 
 	def set_config(self, **cfg):
 
-		# Add synonyms to keylist
+		# Add synonyms to buttonlist
 		if u'buttonlist' in cfg and isinstance(cfg[u'buttonlist'], list):
 			try:
 				cfg[u'buttonlist'] = \
@@ -192,8 +192,12 @@ class Mouse(Backend):
 			Immediately changes the visibility of the mouse cursor.
 
 			__Note:__ In most cases, you will want to use the `visible`
-			[keyword][Response keywords], which changes the visibility during
-			response collection, that is, while `mouse.get_click()` is called.
+			keyword, which changes the visibility during response collection,
+			that is, while `mouse.get_click()` is called. Calling 
+			`show_cursor()` will not implicitly change the value of `visible`, 
+			which can lead to the somewhat unintuitive behavior that the cursor
+			is hidden as soon as `get_click()` is called.
+			
 
 		keywords:
 			show:
@@ -234,8 +238,9 @@ class Mouse(Backend):
 
 		keyword-dict:
 			resp_args:
-				Optional [response keywords] that will be used for this call to
-				[mouse.get_click]. This does not affect subsequent operations.
+				Optional [response keywords](#response-keywords) that will be
+				used for this call to `Mouse.get_click()`. This does not affect
+				subsequent operations.
 
 		returns:
 			desc:			A (button, position, timestamp) tuple. The button
@@ -266,9 +271,9 @@ class Mouse(Backend):
 
 		keyword-dict:
 			resp_args:
-				Optional [response keywords] that will be used for this call to
-				[mouse.get_click_release]. This does not affect subsequent
-				operations.
+				Optional [response keywords](#response-keywords) that will be
+				used for this call to `Mouse.get_click_release()`. This does
+				not affect subsequent operations.
 
 		returns:
 			desc:			A (button, position, timestamp) tuple. The button
